{% load i18n %} {% comment %} {% endcomment %} {% if controller.paging %}
{% if controller.paging.prev %}{% trans "preview" %}{% endif %} {% trans "Page" %} {% for p in controller.paging.total %} {% if controller.paging.page == p %} {{ p }} {% else %} {% if p == -1 %} ... {% else %} {{ p }} {% endif %} {% endif %} {% endfor %} {% if controller.paging.next %}{% trans "next" %}{% endif %}
{% endif %}